@@ -12,10 +12,7 @@ OC.L10N.register(
     "Add" : "যোগ করুন",
     "First name" : "নামের প্রথমাংশ ",
     "Last name" : "নামের শেষাংশ",
-    "Password protection" : "Password protection",
     "Save" : "সংরক্ষণ",
-    "Description" : "বিবরণ",
-    "Settings" : "Settings",
     "Cancel" : "বাতির",
     "Invalid image" : "অবৈধ চিত্র",
     "Name" : "নাম",
