@@ -154,8 +154,10 @@ OC.L10N.register(
     "Groups" : "グループ",
     "Search contacts …" : "連絡先を検索...",
     "Add to {group}" : "{group}に追加",
+    "Add members to {group}" : "ユーザーを{group}に追加",
     "Remove {type}" : "{type} を削除",
     "Add to group" : "グループに追加",
+    "Add members to group" : "ユーザーをグループに追加",
     "Search {types}" : "{types} を検索",
     "Search for people to add" : "追加するメンバーを検索",
     "No results" : "該当なし",
@@ -183,6 +185,7 @@ OC.L10N.register(
     "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
     "Add to {circle}" : "{circle} に追加",
+    "Invite members to {circle}" : "メンバーに{circle} に参加するように招待します",
     "Pending" : "保留中",
     "Select chart …" : "組織図を選択...",
     "Chart" : "チャート",
