@@ -18,10 +18,7 @@ OC.L10N.register(
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
     "Last modified" : "ბოლო ცვლილება",
-    "Password protection" : "პაროლით თავდაცვა",
     "Save" : "შენახვა",
-    "Description" : "აღწერილობა",
-    "Settings" : "Settings",
     "Cancel" : "უარყოფა",
     "Invalid image" : "არასწორი სურათი",
     "Address book" : "მისამართების წიგნი",
@@ -31,6 +28,7 @@ OC.L10N.register(
     "No results" : "შედეგები არაა",
     "Pending" : "მოლოდინში",
     "None" : "არც ერთი",
+    "Member" : "წევრი",
     "New contact" : "ახალი კონტაქტი",
     "Close" : "დახურვა",
     "Import" : "იმპორტი",
@@ -39,10 +37,10 @@ OC.L10N.register(
     "Group" : "ჯგუფი",
     "Email" : "ელ-ფოსტა",
     "Contact" : "კონტაქტი",
-    "Member" : "წევრი",
     "Moderator" : "მოდერატორი",
     "Admin" : "ადმინისტრატორი",
     "Owner" : "მფლობელი",
+    "Privacy" : "კონფიდენციალურობა",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
     "Prefix" : "პრეფიქსი",
