@@ -22,9 +22,7 @@ OC.L10N.register(
     "Last name" : "Mbiemër",
     "Display name" : "Shfaq emrin",
     "Last modified" : "Ndryshuar së fundmi",
-    "Password protection" : "Password protection",
     "Save" : "Ruaj",
-    "Description" : "Përshkrim",
     "Cancel" : "Anullo",
     "Invalid image" : "Figurë e pavlefshme",
     "Pick an avatar" : "Zgjidh një avatar",
@@ -52,6 +50,7 @@ OC.L10N.register(
     "Select type" : "Zgjidhni llojin",
     "Add contact in group" : "Shto kontaktin në grup",
     "None" : "Asnjë",
+    "Member" : "Anëtar",
     "New contact" : "Kontakt i ri",
     "Close" : "Mbylleni",
     "Import" : "Import",
@@ -60,10 +59,10 @@ OC.L10N.register(
     "Group" : "Grup",
     "Email" : "Email",
     "Contact" : "Kontakt",
-    "Member" : "Anëtar",
     "Moderator" : "Moderator",
     "Admin" : "Administrator",
     "Owner" : "Zotëruesi",
+    "Privacy" : "Privatësia",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
     "Prefix" : "Parashtesë",
